Base

Enum Base 

pub enum Base {
Show 25 variants Identity, Base2, Base8, Base10, Base16Lower, Base16Upper, Base32Lower, Base32Upper, Base32PadLower, Base32PadUpper, Base32HexLower, Base32HexUpper, Base32HexPadLower, Base32HexPadUpper, Base32Z, Base36Lower, Base36Upper, Base45, Base58Flickr, Base58Btc, Base64, Base64Pad, Base64Url, Base64UrlPad, Base256Emoji,
}
List of types currently supported in the multibase spec.

Not all base types are supported by this library.

Variants



Identity

8-bit binary (encoder and decoder keeps data unmodified).



Base2

Base2 (alphabet: 01).



Base8

Base8 (alphabet: 01234567).



Base10

Base10 (alphabet: 0123456789).



Base16Lower

Base16 lower hexadecimal (alphabet: 0123456789abcdef).



Base16Upper

Base16 upper hexadecimal (alphabet: 0123456789ABCDEF).



Base32Lower

Base32, rfc4648 no padding (alphabet: abcdefghijklmnopqrstuvwxyz234567).



Base32Upper

Base32, rfc4648 no padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZ234567).



Base32PadLower

Base32, rfc4648 with padding (alphabet: abcdefghijklmnopqrstuvwxyz234567).



Base32PadUpper

Base32, rfc4648 with padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZ234567).



Base32HexLower

Base32hex, rfc4648 no padding (alphabet: 0123456789abcdefghijklmnopqrstuv).



Base32HexUpper

Base32hex, rfc4648 no padding (alphabet: 0123456789ABCDEFGHIJKLMNOPQRSTUV).



Base32HexPadLower

Base32hex, rfc4648 with padding (alphabet: 0123456789abcdefghijklmnopqrstuv).



Base32HexPadUpper

Base32hex, rfc4648 with padding (alphabet: 0123456789ABCDEFGHIJKLMNOPQRSTUV).



Base32Z

z-base-32 (used by Tahoe-LAFS) (alphabet: ybndrfg8ejkmcpqxot1uwisza345h769).



Base36Lower

Base36, [0-9a-z] no padding (alphabet: 0123456789abcdefghijklmnopqrstuvwxyz).



Base36Upper

Base36, [0-9A-Z] no padding (alphabet: 0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ).



Base45

Base45, rfc9285 (alphabet: 0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:).



Base58Flickr

Base58 flicker (alphabet: 123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ).



Base58Btc

Base58 bitcoin (alphabet: 123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz).



Base64

Base64, rfc4648 no padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/).



Base64Pad

Base64, rfc4648 with padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/).



Base64Url

Base64 url, rfc4648 no padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_).



Base64UrlPad

Base64 url, rfc4648 with padding (alphabet: ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_).



Base256Emoji

Base256Emoji (alphabet: 🚀🪐☄🛰🌌🌑🌒🌓🌔🌕🌖🌗🌘🌍🌏🌎🐉☀💻🖥💾💿😂❤😍🤣😊🙏💕😭😘👍😅👏😁🔥🥰💔💖💙😢🤔😆🙄💪😉☺👌🤗💜😔😎😇🌹🤦🎉💞✌✨🤷😱😌🌸🙌😋💗💚😏💛🙂💓🤩😄😀🖤😃💯🙈👇🎶😒🤭❣😜💋👀😪😑💥🙋😞😩😡🤪👊🥳😥🤤👉💃😳✋😚😝😴🌟😬🙃🍀🌷😻😓⭐✅🥺🌈😈🤘💦✔😣🏃💐☹🎊💘😠☝😕🌺🎂🌻😐🖕💝🙊😹🗣💫💀👑🎵🤞😛🔴😤🌼😫⚽🤙☕🏆🤫👈😮🙆🍻🍃🐶💁😲🌿🧡🎁⚡🌞🎈❌✊👋😰🤨😶🤝🚶💰🍓💢🤟🙁🚨💨🤬✈🎀🍺🤓😙💟🌱😖👶🥴▶➡❓💎💸⬇😨🌚🦋😷🕺⚠🙅😟😵👎🤲🤠🤧📌🔵💅🧐🐾🍒😗🤑🌊🤯🐷☎💧😯💆👆🎤🙇🍑❄🌴💣🐸💌📍🥀🤢👅💡💩👐📸👻🤐🤮🎼🥵🚩🍎🍊👼💍📣🥂)

Implementations

Source

impl Base

pub fn from_code(code: char) -> Result<Self>

Convert a number to the matching base algorithm, or Error if no algorithm is matching.

pub fn code(&self) -> char

Get the code corresponding to the base algorithm.

pub fn encode<I: AsRef<[u8]>>(&self, input: I) -> String

Encode the given byte slice to base string.

pub fn decode<I: AsRef<str>>(&self, input: I) -> Result<Vec<u8>>

Decode the base string.